about summary refs log tree commit diff
path: root/editor/pnmstitch.c
diff options
context:
space:
mode:
Diffstat (limited to 'editor/pnmstitch.c')
-rw-r--r--editor/pnmstitch.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/editor/pnmstitch.c b/editor/pnmstitch.c
index 45aee2f4..849445fb 100644
--- a/editor/pnmstitch.c
+++ b/editor/pnmstitch.c
@@ -77,7 +77,7 @@
  *      - Add RotateCrop filter algorithm (in-memory copy of image,
  *        detect least loss horizontal crop on a rotated image).
  *      - pnmstitch should be generalized to handle transformation
- *        occuring on the left image, currently it blends assuming
+ *        occurring on the left image, currently it blends assuming
  *        that there is no transformation effects on the left image.
  *      - user selectable blending algorithms?
  */
@@ -233,7 +233,7 @@ parseCommandLine ( int argc, char ** argv,
    was passed to us as the argv array.  We also trash *argv.
 -----------------------------------------------------------------------------*/
     optEntry *option_def = malloc( 100*sizeof( optEntry ) );
         /* Instructions to optParseOptions3 on how to parse our options.
          */
     optStruct3 opt;
 
@@ -265,7 +265,7 @@ parseCommandLine ( int argc, char ** argv,
     opt.short_allowed = FALSE;  /* We have no short (old-fashioned) options */
     opt.allowNegNum = FALSE;  /* We have no parms that are negative numbers */
 
-    optParseOptions3( &argc, argv, opt, sizeof(opt), 0);
+    pm_optParseOptions3( &argc, argv, opt, sizeof(opt), 0);
         /* Uses and sets argc, argv, and some of *cmdlineP and others. */
 
     if (!widthSpec) {
@@ -370,7 +370,7 @@ static void
 free_image(Image * image)
 {
     if (image->name) {
-        strfree(image->name);
+        pm_strfree(image->name);
         image->name = NULL;     
     }
     if (image->tuple) {
@@ -405,14 +405,14 @@ openWithPossibleExtension(const char *  const baseName,
         
         const char * trialName;
         
-        asprintfN(&trialName, "%s%s", baseName, extlist[extIndex]);
+        pm_asprintf(&trialName, "%s%s", baseName, extlist[extIndex]);
         
         ifP = fopen(trialName, "rb");
         
         if (ifP)
             *filenameP = trialName;
         else
-            strfree(trialName);
+            pm_strfree(trialName);
     }
     if (!ifP) 
         pm_error ("Failed to open input file named '%s' "
@@ -470,7 +470,7 @@ writeinit(Image * image)
 {
     if (streq(image->name, "-")) {
         image->pam.file = stdout;
-        strfree(image->name);
+        pm_strfree(image->name);
         image->name = strdup("<stdout>");
     } else {
         image->pam.file = pm_openw(image->name);
@@ -893,7 +893,7 @@ stitchOneRow(Image *    const Left,
      *  We scale the overlap of the left and right images, we need to
      * discover and hold on to the left edge of the right image to
      * determine the rate at which we blend. Most (7/8) of the blending
-     * occurs in the first half of the overlap to reduce the occurences
+     * occurs in the first half of the overlap to reduce the occurrences
      * of blending artifacts. If there is no overlap, the image present
      * has no blending activity, this is determined by the black
      * background and is not through an alpha layer to help reduce
@@ -1393,7 +1393,7 @@ LinearConstrain(Stitcher * me, int x, int y, int width, int height)
  *  width sliver of the left hand side of the right image and compare
  *  the sample to the left hand image. Accuracy is honored over speed.
  *  The image overlap is expected between 7/16 to 1/16 in the horizontal
- *  position, and a minumum of 5/8 in the vertical dimension.
+ *  position, and a minimum of 5/8 in the vertical dimension.
  *
  *  Blind alleys:
  *      - reduced resolution can match in totally wrong regions,
@@ -2071,7 +2071,7 @@ BiLinearConstrain(Stitcher * me, int x, int y, int width, int height)
  *  width sliver of the left hand side of the right image and compare
  *  the sample to the left hand image. Accuracy is honored over speed.
  *  The image overlap is expected between 7/16 to 1/16 in the horizontal
- *  position, and a minumum of 5/8 in the vertical dimension.
+ *  position, and a minimum of 5/8 in the vertical dimension.
  *
  *  Blind alleys:
  *      - Tried a simpler constraint for right side to be `back'
@@ -233,7 +233,7 @@ parseCommandLine ( int argc, char ** argv,
 -----------------------------------------------------------------------------*/
     optEntry *option_def = malloc( 100*sizeof( optEntry ) );
-        /* Instructions to optParseOptions3 on how to parse our options.
+        /* Instructions to pm_optParseOptions3 on how to parse our options.
          */
     optStruct3 opt;